✨ A simple library for creating beautiful interactive prompts.

.. image:: https://github.com/Exahilosys/survey/raw/master/images/showcase.gif

Features
--------

- **Pythonic**: Friendly interface wrapped around simple functions.
- **Lightweight**: Independent of any other prompt or visual libraries.
- **Adaptable**: Works with any string formatting and window size.
- **Extensive**: Packed with tweaks and features for any situation.

Installing
----------

.. code-block::

    pip3 install survey

Links
-----

- Check out the `Quickstart <https://survey.readthedocs.io/quickstart.html>`_ guide for more.
- Greatly inspired by `AlecAivazis's GoLang <https://github.com/AlecAivazis/survey>`_ library.

Suggestions and contributions are greatly appreciated!
